@@ -6,7 +6,7 @@ if (any(is.na(x) | (x < 0)) || max(abs(x - y)) > 1e-07)
         stop("'x' must be nonnegative and integer")
 z<-round(n)
  if (length(size) != length(prob) || is.na(n) || (n < 1) || abs(n - 
-            z) > 1e-07 || (x > z)) 
+            z) > 1e-07 || any(x > z)) 
             stop("'size' must contain positive integers and their sum must be  >= 'x'")
 if (any(is.na(prob)| (prob<0) | (prob>1) ))
 stop("'prob' must contain numbers between 0 und 1")
